@@ -6,7 +6,7 @@
 
 /* as defined in sdkddkver.h */
 #ifndef _WIN32_WINNT
-#define _WIN32_WINNT 0x0600 /* Vista */
+#define _WIN32_WINNT 0x0601 /* Windows 7 */
 #endif
 /* reduces the number of implicitly included headers */
 #ifndef WIN32_LEAN_AND_MEAN
@@ -67,6 +67,7 @@ struct ethhdr {
     unsigned short h_proto; /* packet type ID field */
 };
 
+SLIRP_PACKED_BEGIN
 struct slirp_arphdr {
     unsigned short ar_hrd; /* format of hardware address */
     unsigned short ar_pro; /* format of protocol address */
@@ -81,7 +82,7 @@ struct slirp_arphdr {
     uint32_t ar_sip; /* sender IP address       */
     uint8_t ar_tha[ETH_ALEN]; /* target hardware address */
     uint32_t ar_tip; /* target IP address       */
-} SLIRP_PACKED;
+} SLIRP_PACKED_END;
 
 #define ARP_TABLE_SIZE 16
 
@@ -90,9 +91,11 @@ typedef struct ArpTable {
     int next_victim;
 } ArpTable;
 
+/* Add a new ARP entry for the given addresses */
 void arp_table_add(Slirp *slirp, uint32_t ip_addr,
                    const uint8_t ethaddr[ETH_ALEN]);
 
+/* Look for an ARP entry for the given IP address */
 bool arp_table_search(Slirp *slirp, uint32_t ip_addr,
                       uint8_t out_ethaddr[ETH_ALEN]);
 
@@ -114,11 +117,15 @@ typedef struct NdpTable {
     int next_victim;
 } NdpTable;
 
+/* Add a new NDP entry for the given addresses */
 void ndp_table_add(Slirp *slirp, struct in6_addr ip_addr,
                    uint8_t ethaddr[ETH_ALEN]);
+
+/* Look for an NDP entry for the given IPv6 address */
 bool ndp_table_search(Slirp *slirp, struct in6_addr ip_addr,
                       uint8_t out_ethaddr[ETH_ALEN]);
 
+/* Slirp configuration, specified by the application */
 struct Slirp {
     int cfg_version;
 
@@ -151,6 +158,9 @@ struct Slirp {
 
     bool disable_host_loopback;
 
+    uint32_t mfr_id;
+    uint8_t oob_eth_addr[ETH_ALEN];
+
     /* mbuf states */
     struct slirp_quehead m_freelist;
     struct slirp_quehead m_usedlist;
@@ -207,81 +217,170 @@ struct Slirp {
     bool disable_dns; /* slirp will not redirect/serve any DNS packet */
 };
 
+/*
+ * Send one packet from each session.
+ * If there are packets on the fastq, they are sent FIFO, before
+ * everything else.  Then we choose the first packet from each
+ * batchq session (socket) and send it.
+ * For example, if there are 3 ftp sessions fighting for bandwidth,
+ * one packet will be sent from the first session, then one packet
+ * from the second session, then one packet from the third.
+ */
 void if_start(Slirp *);
 
+/* Get the address of the DNS server on the host side */
 int get_dns_addr(struct in_addr *pdns_addr);
+
+/* Get the IPv6 address of the DNS server on the host side */
 int get_dns6_addr(struct in6_addr *pdns6_addr, uint32_t *scope_id);
 
 /* ncsi.c */
+
+/* Process NCSI packet coming from the guest */
 void ncsi_input(Slirp *slirp, const uint8_t *pkt, int pkt_len);
 
 #ifndef _WIN32
 #include <netdb.h>
 #endif
 
-
+/* Whether we should send TCP keepalive packets */
 extern bool slirp_do_keepalive;
 
 #define TCP_MAXIDLE (TCPTV_KEEPCNT * TCPTV_KEEPINTVL)
 
 /* dnssearch.c */
+/* Translate from vdnssearch in configuration, into Slirp */
 int translate_dnssearch(Slirp *s, const char **names);
 
 /* cksum.c */
+/* Compute the checksum of the mbuf */
 int cksum(struct mbuf *m, int len);
+/* Compute the checksum of the mbuf which contains an IPv6 packet */
 int ip6_cksum(struct mbuf *m);
 
 /* if.c */
+/* Called from slirp_new */
 void if_init(Slirp *);
+/* Queue packet into an output queue (fast or batch), for sending to the guest */
 void if_output(struct socket *, struct mbuf *);
 
 /* ip_input.c */
+/* Called from slirp_new */
 void ip_init(Slirp *);
+/* Called from slirp_cleanup */
 void ip_cleanup(Slirp *);
+/* Process IPv4 packet coming from the guest */
 void ip_input(struct mbuf *);
+/*
+ * IP timer processing;
+ * if a timer expires on a reassembly
+ * queue, discard it.
+ */
 void ip_slowtimo(Slirp *);
-void ip_stripoptions(register struct mbuf *, struct mbuf *);
+/*
+ * Strip out IP options, at higher
+ * level protocol in the kernel.
+ */
+void ip_stripoptions(register struct mbuf *);
 
 /* ip_output.c */
+/* Send IPv4 packet to the guest */
 int ip_output(struct socket *, struct mbuf *);
 
 /* ip6_input.c */
+/* Called from slirp_new, but after other initialization */
 void ip6_post_init(Slirp *);
+/* Called from slirp_cleanup */
 void ip6_cleanup(Slirp *);
+/* Process IPv6 packet coming from the guest */
 void ip6_input(struct mbuf *);
 
 /* ip6_output */
+/* Send IPv6 packet to the guest */
 int ip6_output(struct socket *, struct mbuf *, int fast);
 
 /* tcp_input.c */
+/* Process TCP datagram coming from the guest */
 void tcp_input(register struct mbuf *, int, struct socket *, unsigned short af);
-int tcp_mss(register struct tcpcb *, unsigned);
+/* Determine a reasonable value for maxseg size */
+int tcp_mss(register struct tcpcb *, unsigned offer);
 
 /* tcp_output.c */
+/* Send TCP datagram to the guest */
 int tcp_output(register struct tcpcb *);
+/* Start/restart persistence timer */
 void tcp_setpersist(register struct tcpcb *);
 
 /* tcp_subr.c */
+/* Called from slirp_new */
 void tcp_init(Slirp *);
+/* Called from slirp_cleanup */
 void tcp_cleanup(Slirp *);
+/*
+ * Create template to be used to send tcp packets on a connection.
+ * Call after host entry created, fills
+ * in a skeletal tcp/ip header, minimizing the amount of work
+ * necessary when the connection is used.
+ */
 void tcp_template(struct tcpcb *);
+/*
+ * Send a single message to the TCP at address specified by
+ * the given TCP/IP header.
+ */
 void tcp_respond(struct tcpcb *, register struct tcpiphdr *,
                  register struct mbuf *, tcp_seq, tcp_seq, int, unsigned short);
+/*
+ * Create a new TCP control block, making an
+ * empty reassembly queue and hooking it to the argument
+ * protocol control block.
+ */
 struct tcpcb *tcp_newtcpcb(struct socket *);
+/*
+ * Close a TCP control block:
+ *	discard all space held by the tcp
+ *	discard internet protocol block
+ *	wake up any sleepers
+ */
 struct tcpcb *tcp_close(register struct tcpcb *);
+/* The Internet socket got closed, tell the guest */
 void tcp_sockclosed(struct tcpcb *);
+/*
+ * Connect to a host on the Internet
+ * Called by tcp_input
+ */
 int tcp_fconnect(struct socket *, unsigned short af);
+/* Accept the connection from the Internet, and connect to the guest */
 void tcp_connect(struct socket *);
+/* Attach a TCPCB to a socket */
 void tcp_attach(struct socket *);
+/* * Return TOS according to the ports */
 uint8_t tcp_tos(struct socket *);
+/*
+ * We received a packet from the guest.
+ *
+ * Emulate programs that try and connect to us
+ * This includes ftp (the data connection is
+ * initiated by the server) and IRC (DCC CHAT and
+ * DCC SEND) for now
+ */
 int tcp_emu(struct socket *, struct mbuf *);
+/* Configure the socket, now that the guest completed accepting the connection */
 int tcp_ctl(struct socket *);
+/*
+ * Drop a TCP connection, reporting
+ * the specified error.  If connection is synchronized,
+ * then send a RST to peer.
+ */
 struct tcpcb *tcp_drop(struct tcpcb *tp, int err);
 
+/* Find the socket for the guest address and port */
 struct socket *slirp_find_ctl_socket(Slirp *slirp, struct in_addr guest_addr,
                                      int guest_port);
 
+/* Send a frame to the virtual Ethernet board, i.e. call the application send_packet callback */
 void slirp_send_packet_all(Slirp *slirp, const void *buf, size_t len);
+
+/* Create a new timer, i.e. call the application timer_new callback */
 void *slirp_timer_new(Slirp *slirp, SlirpTimerId id, void *cb_opaque);
 
 #endif
