@@ -56,7 +56,7 @@ void udp_cleanup(Slirp *slirp)
 
     for (so = slirp->udb.so_next; so != &slirp->udb; so = so_next) {
         so_next = so->so_next;
-        udp_detach(slirp->udb.so_next);
+        udp_detach(so);
     }
 }
 
@@ -89,7 +89,7 @@ void udp_input(register struct mbuf *m, int iphlen)
      * with options still present.
      */
     if (iphlen > sizeof(struct ip)) {
-        ip_stripoptions(m, (struct mbuf *)0);
+        ip_stripoptions(m);
         iphlen = sizeof(struct ip);
     }
 
